@@ -12,12 +12,13 @@ from astro.utils.dataframe import convert_columns_names_capitalization
 class JSONFileType(FileType):
     """Concrete implementation to handle JSON file type"""
 
+    # We need skipcq because it's a method overloading so we don't want to make it a static method
     def export_to_dataframe(
         self,
         stream: io.TextIOWrapper,
         columns_names_capitalization="original",
         **kwargs,
-    ) -> pd.DataFrame:
+    ) -> pd.DataFrame:  # skipcq PYL-R0201
         """read json file from one of the supported locations and return dataframe
 
         :param stream: file stream object
@@ -33,7 +34,8 @@ class JSONFileType(FileType):
         )
         return df
 
-    def create_from_dataframe(self, df: pd.DataFrame, stream: io.TextIOWrapper) -> None:
+    # We need skipcq because it's a method overloading so we don't want to make it a static method
+    def create_from_dataframe(self, df: pd.DataFrame, stream: io.TextIOWrapper) -> None:  # skipcq PYL-R0201
         """Write json file to one of the supported locations
 
         :param df: pandas dataframe
